: ==== start ====
: test for attaching non-existant device
ipsec tncfg --attach --virtual ipsec0 --physical xxx
: ==== end ====

